diff -r 086c9c2c52b9 lib/galaxy/tools/parameters/basic.py
--- a/lib/galaxy/tools/parameters/basic.py	Sun Apr 03 12:47:39 2011 -0400
+++ b/lib/galaxy/tools/parameters/basic.py	Mon Apr 04 11:15:10 2011 -0400
@@ -151,11 +151,11 @@
             raise ValueError( "Unknown tool parameter type '%s'" % param_type )
         else:
             return parameter_types[param_type]( tool, param )
-        
+
 class TextToolParameter( ToolParameter ):
     """
     Parameter that can take on any text value.
-    
+
     >>> p = TextToolParameter( None, XML( '<param name="blah" type="text" size="4" value="default" />' ) )
     >>> print p.name
     blah
@@ -177,6 +177,24 @@
             return form_builder.TextField( self.name, self.size, value )
     def get_initial_value( self, trans, context ):
         return self.value
+                
+class PasswordToolParameter( TextToolParameter ):
+    """
+    Password text parameter.
+    
+    >>> p = PasswordToolParameter( None, XML( '<param name="blah" type="password" size="4" value="default" />' ) )
+    >>> print p.name
+    blah
+    >>> print p.get_html()
+    <input type="password" name="blah" size="4" value="default">
+    >>> print p.get_html( value="meh" )
+    <input type="password" name="blah" size="4" value="meh">
+    """
+    def get_html_field( self, trans=None, value=None, other_values={} ):
+        if value is None: value = self.value
+        return form_builder.PasswordField( self.name, self.size, value )
+    def get_initial_value( self, trans, context ):
+        return self.value
 
 class IntegerToolParameter( TextToolParameter ):
     """
@@ -1511,6 +1529,7 @@
 #         return self.html
 
 parameter_types = dict( text        = TextToolParameter,
+                        password    = PasswordToolParameter,
                         integer     = IntegerToolParameter,
                         float       = FloatToolParameter,
                         boolean     = BooleanToolParameter,
